@@ -160,8 +160,8 @@ impl<D: BodyDecode> Decode for RequestDecoder<D> {
         Ok((size, item))
     }
 
-    fn has_terminated(&self) -> bool {
-        self.0.has_terminated()
+    fn is_idle(&self) -> bool {
+        self.0.is_idle()
     }
 
     fn requiring_bytes(&self) -> ByteCount {
@@ -198,8 +198,8 @@ impl Decode for RequestLineDecoder {
         Ok((size, item))
     }
 
-    fn has_terminated(&self) -> bool {
-        false
+    fn is_idle(&self) -> bool {
+        self.0.is_idle()
     }
 
     fn requiring_bytes(&self) -> ByteCount {
